/*
** Module   : XEntity
** Abstract : DOM XML document and nodereference common interface.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 EVL 20130130 Created initial version.
** 002 EVL 20130204 Major rework to use w3c backend.
*/

package com.goldencode.p2j.xml;

import org.w3c.dom.*;
import com.goldencode.p2j.util.*;

/**
 * Interface decribing the common features for X-Docunet and X-Node-Reference
 * Progress DOM XML support objects.
 */
public interface XEntity
extends WrappedResource
{
   /**
    * Getting the Element backend object for this XEntity.
    * 
    * @return   The Element associated with object.
    */
   public Element getNode();
   
   /**
    * Gets the handle object associated with either XDocument or
    * X-Node-Reference object.
    * 
    * @return   The handle associated with object.
    */
   public handle getHandle();

   // Attributes
   /**
    * Gets the the number of children objects for the current one.
    * 
    * @return   The integer number of the children.
    */
   public integer getNumChildren();

   /**
    * Gets the the unique ID number associated to this object by the
    * underlying system. Not the same as the handle value itself.
    * 
    * @return   The integer number of the children.
    */
   public integer getUniqId();

   // Methods
   /**
    * Appending the new child to the current object.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be appended.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical appendChild(handle hChild);

   /**
    * Appending the new child to the current object.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be appended.
    * @param    name
    *           The name of the child to be appended.
    * @param    type
    *           The type of the child to be appended.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical appendChild(handle hChild, character name, character type);

   // Returning value placed into hChild
   /**
    * Getting the handle object of the child node with specified index.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to put
    *           the results.
    * @param    index
    *           1-based index of the child node to be retrieved.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical getChild(handle hChild, integer index);
   
   /**
    * Getting the handle object of the child node with specified index.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to put
    *           the results.
    * @param    index
    *           1-based index of the child node to be retrieved.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical getChild(handle hChild, int index);
   
   /**
    * Removing the specified child from the node.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be removed.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical removeChild(handle hChild);
}
